@import 'layout/main/compute/compute.scss';
@import 'alarmList/alarmList.scss';
@import 'components/sunburst/sunburst.scss';
@import 'components/alarms/alarms.scss';
@import 'components/rca/rootCauseAnalysisGraph.scss';
@import 'components/rca/rcaContainer.scss';
@import 'components/information/information.scss';
@import 'entities/graph/entities-graph.scss';
@import 'entities/info/entities-info.scss';
@import 'entities/toolbox/entities-toolbox.scss';
@import 'entities/entities.scss';
@import 'templateList/templateList.scss';
@import 'components/template/templateContainer.scss';

.red {
  color: #FA3C3C;
}

.orange {
  color: #fc9d00;
}

.yellow {
  color: #FFC600;
}

.green {
  color: #87CE53;
}

.olive {
  color: #97A560;
}

.gray {
  color: #AEAEAE;
}

.ellipsis {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}